from django.conf import settings
from abc import ABC, abstractmethod

from ..middlewares.datasource_middleware import get_current_datasource


class DataBaseRouter(ABC):
    @abstractmethod
    def db_for_read(self, model, **hints):
        pass

    @abstractmethod
    def db_for_write(self, model, **hints):
        pass


class DataSourceRouter(DataBaseRouter):
    def get_current_db(self):
        db_default = getattr(settings, 'DB_DEFAULT', 'default')
        datasource = get_current_datasource(default=db_default)
        return datasource

    def db_for_read(self, model, **hints):
        return self.get_current_db()

    def db_for_write(self, model, **hints):
        return self.get_current_db()