import threading

from django.conf import settings
from django.db import connections
from django.http import Http404

THREAD_LOCAL = threading.local()


class DataSourceMiddleware:
    def __init__(self, get_response):
        self.get_response = get_response

    def __call__(self, request):
        db_default = getattr(settings, 'DB_DEFAULT', 'default')
        datasource = get_datasource_from_request(
            request, default=db_default, raise_exception=True
        )
        set_current_datasource(datasource)
        response = self.get_response(request)
        return response


def get_datasource_from_request(request, default=None, raise_exception=False):
    datasource = request.META.get("HTTP_DATA_SOURCE", default)
    connection_not_found = datasource and datasource not in connections
    if connection_not_found and raise_exception:
        raise Http404
    return default if connection_not_found else datasource


def get_current_datasource(default=None):
    return getattr(THREAD_LOCAL, "datasource", default)


def set_current_datasource(datasource):
    setattr(THREAD_LOCAL, "datasource", datasource)