import logging

from opencensus.ext.django.middleware import (
    HTTP_STATUS_CODE,
    SPAN_THREAD_LOCAL_KEY,
    OpencensusMiddleware,
)
from opencensus.trace import execution_context, utils


def _set_django_attributes(span, request):
    django_user = getattr(request, "user", None)

    if django_user and not hasattr(django_user, "codigo"):
        return

    user_id = django_user.codigo
    user_name = django_user.login

    if user_id is not None:
        span.add_attribute("django.user.id", str(user_id))

    if user_name is not None:
        span.add_attribute("django.user.name", str(user_name))


def _get_django_span():
    return execution_context.get_opencensus_attr(SPAN_THREAD_LOCAL_KEY)


def _get_current_tracer():
    return execution_context.get_opencensus_tracer()


log = logging.getLogger(__name__)


class OpencensusMiddlewareHapUser(OpencensusMiddleware):
    def process_response(self, request, response):
        if utils.disable_tracing_url(request.path, self.excludelist_paths):
            return response

        try:
            span = _get_django_span()
            span.add_attribute(
                attribute_key=HTTP_STATUS_CODE, attribute_value=response.status_code
            )

            _set_django_attributes(span, request)

            tracer = _get_current_tracer()
            tracer.end_span()
            tracer.finish()
        except Exception:
            log.error("Failed to trace request", exc_info=True)

        return response