from django.conf import settings
from django.http import JsonResponse
from opencensus.trace import execution_context
from djangorestframework_camel_case.render import camelize


def get_response(request, response):
    notifications = []

    camelize_response = getattr(settings, 'CAMELIZE_RESPONSE', False)

    if hasattr(request, "trace"):
        for trace_router in request.trace:
            notifications.append(
                {
                    "message": getattr(trace_router, "message", ""),
                    "propertyName": getattr(request, "property_name", ""),
                }
            )

    if (
        hasattr(response, "data")
        and type(response.data) is dict
        and "message" in response.data.keys()
    ):
        notifications.append({"message": response.data.get("message", "")})
        del response.data["message"]

    data = camelize(
        {
            "notifications": notifications or "",
            "traceId": execution_context.get_opencensus_tracer().tracer.trace_id,
            "timestamp": request.start_time.isoformat(),
        }
    )

    data["content"] = camelize(getattr(response, "data", [])) if camelize_response else getattr(response, "data", [])

    content = JsonResponse(data)

    response.content = content

    if response.status_code == 204:
        response.status_code = 200

    return response